summaryrefslogtreecommitdiffstats
path: root/libkpgp
diff options
context:
space:
mode:
Diffstat (limited to 'libkpgp')
-rw-r--r--libkpgp/kpgpbase.cpp32
-rw-r--r--libkpgp/kpgpbase2.cpp52
-rw-r--r--libkpgp/kpgpbase5.cpp54
-rw-r--r--libkpgp/kpgpbase6.cpp36
-rw-r--r--libkpgp/kpgpbaseG.cpp52
-rw-r--r--libkpgp/kpgpblock.cpp4
-rw-r--r--libkpgp/kpgpblock.h20
-rw-r--r--libkpgp/kpgpui.cpp20
8 files changed, 135 insertions, 135 deletions
diff --git a/libkpgp/kpgpbase.cpp b/libkpgp/kpgpbase.cpp
index d30f0fd1..591a9943 100644
--- a/libkpgp/kpgpbase.cpp
+++ b/libkpgp/kpgpbase.cpp
@@ -70,7 +70,7 @@ Base::run( const char *cmd, const char *passphrase, bool onlyReadFromPGP )
int len, len2;
FILE *pass;
pid_t child_pid;
- int childExitqStatus;
+ int childExiStatus;
struct pollfd pollin, pollout, pollerr;
int pollstatus;
@@ -251,8 +251,8 @@ Base::run( const char *cmd, const char *passphrase, bool onlyReadFromPGP )
do {
//kdDebug(5100) << "Checking if PGP is still running..." << endl;
- childExitqStatus = 0;
- waitpidRetVal = waitpid(child_pid, &childExitqStatus, WNOHANG);
+ childExiStatus = 0;
+ waitpidRetVal = waitpid(child_pid, &childExiStatus, WNOHANG);
//kdDebug(5100) << "waitpid returned " << waitpidRetVal << endl;
if (pout[0] >= 0) {
do {
@@ -351,14 +351,14 @@ Base::run( const char *cmd, const char *passphrase, bool onlyReadFromPGP )
close(ppass[0]);
// Did the child exit normally?
- if (WIFEXITED(childExitqStatus) != 0) {
+ if (WIFEXITED(childExiStatus) != 0) {
// Get the return code of the child
- childExitqStatus = WEXITSTATUS(childExitqStatus);
- kdDebug(5100) << "PGP exited with exit status " << childExitqStatus
+ childExiStatus = WEXITSTATUS(childExiStatus);
+ kdDebug(5100) << "PGP exited with exit status " << childExiStatus
<< endl;
}
else {
- childExitqStatus = -1;
+ childExiStatus = -1;
kdDebug(5100) << "PGP exited abnormally!" << endl;
}
@@ -371,7 +371,7 @@ Base::run( const char *cmd, const char *passphrase, bool onlyReadFromPGP )
*/
kdDebug(5100) << error << endl;
- return childExitqStatus;
+ return childExiStatus;
}
@@ -387,7 +387,7 @@ Base::runGpg( const char *cmd, const char *passphrase, bool onlyReadFromGnuPG )
int len, len2;
FILE *pass;
pid_t child_pid;
- int childExitqStatus;
+ int childExiStatus;
char gpgcmd[1024] = "\0";
struct pollfd poller[3];
int num_pollers = 0;
@@ -529,8 +529,8 @@ Base::runGpg( const char *cmd, const char *passphrase, bool onlyReadFromGnuPG )
do {
//kdDebug(5100) << "Checking if GnuPG is still running..." << endl;
- childExitqStatus = 0;
- waitpidRetVal = waitpid(child_pid, &childExitqStatus, WNOHANG);
+ childExiStatus = 0;
+ waitpidRetVal = waitpid(child_pid, &childExiStatus, WNOHANG);
//kdDebug(5100) << "waitpid returned " << waitpidRetVal << endl;
do {
// poll the pipes
@@ -645,14 +645,14 @@ Base::runGpg( const char *cmd, const char *passphrase, bool onlyReadFromGnuPG )
close(ppass[0]);
// Did the child exit normally?
- if (WIFEXITED(childExitqStatus) != 0) {
+ if (WIFEXITED(childExiStatus) != 0) {
// Get the return code of the child
- childExitqStatus = WEXITSTATUS(childExitqStatus);
- kdDebug(5100) << "GnuPG exited with exit status " << childExitqStatus
+ childExiStatus = WEXITSTATUS(childExiStatus);
+ kdDebug(5100) << "GnuPG exited with exit status " << childExiStatus
<< endl;
}
else {
- childExitqStatus = -1;
+ childExiStatus = -1;
kdDebug(5100) << "GnuPG exited abnormally!" << endl;
}
@@ -663,7 +663,7 @@ Base::runGpg( const char *cmd, const char *passphrase, bool onlyReadFromGnuPG )
// get to know what's going on during the gpg calls.
kdDebug(5100) << "gpg stderr:\n" << error << endl;
- return childExitqStatus;
+ return childExiStatus;
}
diff --git a/libkpgp/kpgpbase2.cpp b/libkpgp/kpgpbase2.cpp
index 97db773a..4ba4043f 100644
--- a/libkpgp/kpgpbase2.cpp
+++ b/libkpgp/kpgpbase2.cpp
@@ -66,7 +66,7 @@ Base2::encsign( Block& block, const KeyIDList& recipients,
const char *passphrase )
{
TQCString cmd;
- int exitqStatus = 0;
+ int exiStatus = 0;
if(!recipients.isEmpty() && passphrase != 0)
cmd = PGP2 " +batchmode +language=en +verbose=1 -seat";
@@ -100,12 +100,12 @@ Base2::encsign( Block& block, const KeyIDList& recipients,
clear();
input = block.text();
- exitqStatus = run(cmd.data(), passphrase);
+ exiStatus = run(cmd.data(), passphrase);
if( !output.isEmpty() )
block.setProcessedText( output );
block.setError( error );
- if(exitqStatus != 0)
+ if(exiStatus != 0)
status = ERROR;
#if 0
@@ -218,7 +218,7 @@ Base2::encsign( Block& block, const KeyIDList& recipients,
}
//kdDebug(5100) << "status = " << status << endl;
- block.setqStatus( status );
+ block.seStatus( status );
return status;
}
@@ -227,11 +227,11 @@ int
Base2::decrypt( Block& block, const char *passphrase )
{
int index, index2;
- int exitqStatus = 0;
+ int exiStatus = 0;
clear();
input = block.text();
- exitqStatus = run(PGP2 " +batchmode +language=en -f", passphrase);
+ exiStatus = run(PGP2 " +batchmode +language=en -f", passphrase);
if( !output.isEmpty() )
block.setProcessedText( output );
block.setError( error );
@@ -249,16 +249,16 @@ Base2::decrypt( Block& block, const char *passphrase )
index1 = input.find('\n', index1);
index2 = input.find("\n\n", index1);
input.remove(index1, index2 - index1);
- exitqStatus = run(PGP2 " +batchmode +language=en -f", passphrase);
+ exiStatus = run(PGP2 " +batchmode +language=en -f", passphrase);
if( !output.isEmpty() )
block.setProcessedText( output );
block.setError( error );
}
- if(exitqStatus == -1) {
+ if(exiStatus == -1) {
errMsg = i18n("error running PGP");
status = RUN_ERR;
- block.setqStatus( status );
+ block.seStatus( status );
return status;
}
@@ -457,7 +457,7 @@ Base2::decrypt( Block& block, const char *passphrase )
}
}
//kdDebug(5100) << "status = " << status << endl;
- block.setqStatus( status );
+ block.seStatus( status );
return status;
}
@@ -467,13 +467,13 @@ Base2::readPublicKey( const KeyID& keyID,
const bool readTrust /* = false */,
Key* key /* = 0 */ )
{
- int exitqStatus = 0;
+ int exiStatus = 0;
status = 0;
- exitqStatus = run( PGP2 " +batchmode +language=en +verbose=0 -kvc -f 0x" +
+ exiStatus = run( PGP2 " +batchmode +language=en +verbose=0 -kvc -f 0x" +
keyID, 0, true );
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return 0;
}
@@ -487,10 +487,10 @@ Base2::readPublicKey( const KeyID& keyID,
if( readTrust )
{
- exitqStatus = run( PGP2 " +batchmode +language=en +verbose=0 -kc -f",
+ exiStatus = run( PGP2 " +batchmode +language=en +verbose=0 -kc -f",
0, true );
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return 0;
}
@@ -512,14 +512,14 @@ Base2::publicKeys( const TQStringList & patterns )
KeyList
Base2::doGetPublicKeys( const TQCString & cmd, const TQStringList & patterns )
{
- int exitqStatus = 0;
+ int exiStatus = 0;
KeyList publicKeys;
status = 0;
if ( patterns.isEmpty() ) {
- exitqStatus = run( cmd, 0, true );
+ exiStatus = run( cmd, 0, true );
- if ( exitqStatus != 0 ) {
+ if ( exiStatus != 0 ) {
status = ERROR;
return KeyList();
}
@@ -533,10 +533,10 @@ Base2::doGetPublicKeys( const TQCString & cmd, const TQStringList & patterns )
for ( TQStringList::ConstIterator it = patterns.begin();
it != patterns.end(); ++it ) {
- exitqStatus = run( cmd + " " + KProcess::quote( *it ).local8Bit(),
+ exiStatus = run( cmd + " " + KProcess::quote( *it ).local8Bit(),
0, true );
- if ( exitqStatus != 0 ) {
+ if ( exiStatus != 0 ) {
status = ERROR;
return KeyList();
}
@@ -576,16 +576,16 @@ int
Base2::signKey(const KeyID& keyID, const char *passphrase)
{
TQCString cmd;
- int exitqStatus = 0;
+ int exiStatus = 0;
cmd = PGP2 " +batchmode +language=en -ks -f ";
cmd += addUserId();
cmd += " 0x" + keyID;
status = 0;
- exitqStatus = run(cmd.data(),passphrase);
+ exiStatus = run(cmd.data(),passphrase);
- if (exitqStatus != 0)
+ if (exiStatus != 0)
status = ERROR;
return status;
@@ -594,16 +594,16 @@ Base2::signKey(const KeyID& keyID, const char *passphrase)
TQCString Base2::getAsciiPublicKey(const KeyID& keyID)
{
- int exitqStatus = 0;
+ int exiStatus = 0;
if (keyID.isEmpty())
return TQCString();
status = 0;
- exitqStatus = run( PGP2 " +batchmode +force +language=en -kxaf 0x" + keyID,
+ exiStatus = run( PGP2 " +batchmode +force +language=en -kxaf 0x" + keyID,
0, true );
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return TQCString();
}
diff --git a/libkpgp/kpgpbase5.cpp b/libkpgp/kpgpbase5.cpp
index 28895739..52a70f01 100644
--- a/libkpgp/kpgpbase5.cpp
+++ b/libkpgp/kpgpbase5.cpp
@@ -66,7 +66,7 @@ Base5::encsign( Block& block, const KeyIDList& recipients,
const char *passphrase )
{
TQCString cmd;
- int exitqStatus = 0;
+ int exiStatus = 0;
int index;
// used to work around a bug in pgp5. pgp5 treats files
// with non ascii chars (umlauts, etc...) as binary files, but
@@ -116,10 +116,10 @@ Base5::encsign( Block& block, const KeyIDList& recipients,
}
//We have to do this otherwise it's all in vain
- exitqStatus = run(cmd.data(), passphrase);
+ exiStatus = run(cmd.data(), passphrase);
block.setError( error );
- if(exitqStatus != 0)
+ if(exiStatus != 0)
status = ERROR;
// now parse the returned info
@@ -185,7 +185,7 @@ Base5::encsign( Block& block, const KeyIDList& recipients,
}
block.setProcessedText( output );
- block.setqStatus( status );
+ block.seStatus( status );
return status;
}
@@ -193,19 +193,19 @@ Base5::encsign( Block& block, const KeyIDList& recipients,
int
Base5::decrypt( Block& block, const char *passphrase )
{
- int exitqStatus = 0;
+ int exiStatus = 0;
clear();
input = block.text();
- exitqStatus = run("pgpv -f +batchmode=1", passphrase);
+ exiStatus = run("pgpv -f +batchmode=1", passphrase);
if( !output.isEmpty() )
block.setProcessedText( output );
block.setError( error );
- if(exitqStatus == -1) {
+ if(exiStatus == -1) {
errMsg = i18n("Error running PGP");
status = RUN_ERR;
- block.setqStatus( status );
+ block.seStatus( status );
return status;
}
@@ -313,7 +313,7 @@ Base5::decrypt( Block& block, const char *passphrase )
}
//kdDebug(5100) << "status = " << status << endl;
- block.setqStatus( status );
+ block.seStatus( status );
return status;
}
@@ -321,12 +321,12 @@ Base5::decrypt( Block& block, const char *passphrase )
Key*
Base5::readPublicKey( const KeyID& keyId, const bool readTrust, Key* key )
{
- int exitqStatus = 0;
+ int exiStatus = 0;
status = 0;
- exitqStatus = run( "pgpk -ll 0x" + keyId, 0, true );
+ exiStatus = run( "pgpk -ll 0x" + keyId, 0, true );
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return 0;
}
@@ -340,9 +340,9 @@ Base5::readPublicKey( const KeyID& keyId, const bool readTrust, Key* key )
if( readTrust )
{
- exitqStatus = run( "pgpk -c 0x" + keyId, 0, true );
+ exiStatus = run( "pgpk -c 0x" + keyId, 0, true );
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return 0;
}
@@ -357,7 +357,7 @@ Base5::readPublicKey( const KeyID& keyId, const bool readTrust, Key* key )
KeyList
Base5::publicKeys( const TQStringList & patterns )
{
- int exitqStatus = 0;
+ int exiStatus = 0;
TQCString cmd = "pgpk -ll";
for ( TQStringList::ConstIterator it = patterns.begin();
@@ -366,9 +366,9 @@ Base5::publicKeys( const TQStringList & patterns )
cmd += KProcess::quote( *it ).local8Bit();
}
status = 0;
- exitqStatus = run( cmd, 0, true );
+ exiStatus = run( cmd, 0, true );
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return KeyList();
}
@@ -386,7 +386,7 @@ Base5::publicKeys( const TQStringList & patterns )
KeyList
Base5::secretKeys( const TQStringList & patterns )
{
- int exitqStatus = 0;
+ int exiStatus = 0;
status = 0;
TQCString cmd = "pgpk -ll";
@@ -396,9 +396,9 @@ Base5::secretKeys( const TQStringList & patterns )
cmd += KProcess::quote( *it ).local8Bit();
}
status = 0;
- exitqStatus = run( cmd, 0, true );
+ exiStatus = run( cmd, 0, true );
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return KeyList();
}
@@ -415,15 +415,15 @@ Base5::secretKeys( const TQStringList & patterns )
TQCString Base5::getAsciiPublicKey(const KeyID& keyID)
{
- int exitqStatus = 0;
+ int exiStatus = 0;
if (keyID.isEmpty())
return TQCString();
status = 0;
- exitqStatus = run( "pgpk -xa 0x" + keyID, 0, true );
+ exiStatus = run( "pgpk -xa 0x" + keyID, 0, true );
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return TQCString();
}
@@ -436,7 +436,7 @@ int
Base5::signKey(const KeyID& keyID, const char *passphrase)
{
TQCString cmd;
- int exitqStatus = 0;
+ int exiStatus = 0;
if(passphrase == 0) return false;
@@ -445,9 +445,9 @@ Base5::signKey(const KeyID& keyID, const char *passphrase)
cmd += addUserId();
status = 0;
- exitqStatus = run(cmd.data(), passphrase);
+ exiStatus = run(cmd.data(), passphrase);
- if (exitqStatus != 0)
+ if (exiStatus != 0)
status = ERROR;
return status;
@@ -579,7 +579,7 @@ Base5::parseKeyData( const TQCString& output, int& offset, Key* key /* = 0 */ )
TQDateTime dt( TQDate( year, month, day ), TQTime( 00, 00 ) );
subkey->setCreationDate( epoch.secsTo( dt ) );
// has the key already expired?
- if( TQDateTime::tqcurrentDateTime() >= dt )
+ if( TQDateTime::currentDateTime() >= dt )
{
subkey->setExpired( true );
key->setExpired( true );
diff --git a/libkpgp/kpgpbase6.cpp b/libkpgp/kpgpbase6.cpp
index 0972a46e..0b507393 100644
--- a/libkpgp/kpgpbase6.cpp
+++ b/libkpgp/kpgpbase6.cpp
@@ -49,19 +49,19 @@ int
Base6::decrypt( Block& block, const char *passphrase )
{
int index, index2;
- int exitqStatus = 0;
+ int exiStatus = 0;
clear();
input = block.text();
- exitqStatus = run( PGP6 " +batchmode +language=C -f", passphrase);
+ exiStatus = run( PGP6 " +batchmode +language=C -f", passphrase);
if( !output.isEmpty() )
block.setProcessedText( output );
block.setError( error );
- if(exitqStatus == -1) {
+ if(exiStatus == -1) {
errMsg = i18n("error running PGP");
status = RUN_ERR;
- block.setqStatus( status );
+ block.seStatus( status );
return status;
}
@@ -180,7 +180,7 @@ Base6::decrypt( Block& block, const char *passphrase )
}
}
//kdDebug(5100) << "status = " << status << endl;
- block.setqStatus( status );
+ block.seStatus( status );
return status;
}
@@ -190,13 +190,13 @@ Base6::readPublicKey( const KeyID& keyID,
const bool readTrust /* = false */,
Key* key /* = 0 */ )
{
- int exitqStatus = 0;
+ int exiStatus = 0;
status = 0;
- exitqStatus = run( PGP6 " +batchmode -compatible +verbose=0 +language=C -kvvc "
+ exiStatus = run( PGP6 " +batchmode -compatible +verbose=0 +language=C -kvvc "
"0x" + keyID, 0, true );
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return 0;
}
@@ -210,10 +210,10 @@ Base6::readPublicKey( const KeyID& keyID,
if( readTrust )
{
- exitqStatus = run( PGP6 " +batchmode -compatible +verbose=0 +language=C -kc "
+ exiStatus = run( PGP6 " +batchmode -compatible +verbose=0 +language=C -kc "
"0x" + keyID, 0, true );
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return 0;
}
@@ -238,13 +238,13 @@ TQStrList
Base6::pubKeys()
{
int index, index2;
- int exitqStatus = 0;
+ int exiStatus = 0;
int compatibleMode = 1;
status = 0;
- exitqStatus = run("pgp +batchmode +language=C -kv -f");
+ exiStatus = run("pgp +batchmode +language=C -kv -f");
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return 0;
}
@@ -319,9 +319,9 @@ Base6::pubKeys()
}
// Also look for pgp key groups
- exitqStatus = run("pgp +batchmode +language=C -gv -f");
+ exiStatus = run("pgp +batchmode +language=C -gv -f");
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return 0;
}
@@ -352,11 +352,11 @@ Base6::secretKeys( const TQStringList & patterns )
int
Base6::isVersion6()
{
- int exitqStatus = 0;
+ int exiStatus = 0;
- exitqStatus = run( PGP6, 0, true );
+ exiStatus = run( PGP6, 0, true );
- if(exitqStatus == -1) {
+ if(exiStatus == -1) {
errMsg = i18n("error running PGP");
status = RUN_ERR;
return 0;
diff --git a/libkpgp/kpgpbaseG.cpp b/libkpgp/kpgpbaseG.cpp
index ecb5af19..adbc84b9 100644
--- a/libkpgp/kpgpbaseG.cpp
+++ b/libkpgp/kpgpbaseG.cpp
@@ -73,7 +73,7 @@ BaseG::encsign( Block& block, const KeyIDList& recipients,
const char *passphrase )
{
TQCString cmd;
- int exitqStatus = 0;
+ int exiStatus = 0;
if(!recipients.isEmpty() && passphrase != 0)
cmd = "--batch --armor --sign --encrypt --textmode";
@@ -109,12 +109,12 @@ BaseG::encsign( Block& block, const KeyIDList& recipients,
clear();
input = block.text();
- exitqStatus = runGpg(cmd.data(), passphrase);
+ exiStatus = runGpg(cmd.data(), passphrase);
if( !output.isEmpty() )
block.setProcessedText( output );
block.setError( error );
- if( exitqStatus != 0 )
+ if( exiStatus != 0 )
{
// this error message is later hopefully overwritten
errMsg = i18n( "Unknown error." );
@@ -199,7 +199,7 @@ BaseG::encsign( Block& block, const KeyIDList& recipients,
}
//kdDebug(5100) << "status = " << status << endl;
- block.setqStatus( status );
+ block.seStatus( status );
return status;
}
@@ -208,19 +208,19 @@ int
BaseG::decrypt( Block& block, const char *passphrase )
{
int index, index2;
- int exitqStatus = 0;
+ int exiStatus = 0;
clear();
input = block.text();
- exitqStatus = runGpg("--batch --decrypt", passphrase);
+ exiStatus = runGpg("--batch --decrypt", passphrase);
if( !output.isEmpty() && ( error.find( "gpg: quoted printable" ) == -1 ) )
block.setProcessedText( output );
block.setError( error );
- if(exitqStatus == -1) {
+ if(exiStatus == -1) {
errMsg = i18n("Error running gpg");
status = RUN_ERR;
- block.setqStatus( status );
+ block.seStatus( status );
return status;
}
@@ -361,7 +361,7 @@ BaseG::decrypt( Block& block, const char *passphrase )
}
}
//kdDebug(5100) << "status = " << status << endl;
- block.setqStatus( status );
+ block.seStatus( status );
return status;
}
@@ -371,15 +371,15 @@ BaseG::readPublicKey( const KeyID& keyID,
const bool readTrust /* = false */,
Key* key /* = 0 */ )
{
- int exitqStatus = 0;
+ int exiStatus = 0;
status = 0;
if( readTrust )
- exitqStatus = runGpg( "--batch --list-public-keys --with-fingerprint --with-colons --fixed-list-mode 0x" + keyID, 0, true );
+ exiStatus = runGpg( "--batch --list-public-keys --with-fingerprint --with-colons --fixed-list-mode 0x" + keyID, 0, true );
else
- exitqStatus = runGpg( "--batch --list-public-keys --with-fingerprint --with-colons --fixed-list-mode --no-expensive-trust-checks 0x" + keyID, 0, true );
+ exiStatus = runGpg( "--batch --list-public-keys --with-fingerprint --with-colons --fixed-list-mode --no-expensive-trust-checks 0x" + keyID, 0, true );
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return 0;
}
@@ -405,7 +405,7 @@ BaseG::readPublicKey( const KeyID& keyID,
KeyList
BaseG::publicKeys( const TQStringList & patterns )
{
- int exitqStatus = 0;
+ int exiStatus = 0;
// the option --with-colons should be used for interprocess communication
// with gpg (according to Werner Koch)
@@ -417,9 +417,9 @@ BaseG::publicKeys( const TQStringList & patterns )
cmd += KProcess::quote( *it ).local8Bit();
}
status = 0;
- exitqStatus = runGpg( cmd, 0, true );
+ exiStatus = runGpg( cmd, 0, true );
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return KeyList();
}
@@ -437,7 +437,7 @@ BaseG::publicKeys( const TQStringList & patterns )
KeyList
BaseG::secretKeys( const TQStringList & patterns )
{
- int exitqStatus = 0;
+ int exiStatus = 0;
// the option --with-colons should be used for interprocess communication
// with gpg (according to Werner Koch)
@@ -449,9 +449,9 @@ BaseG::secretKeys( const TQStringList & patterns )
cmd += KProcess::quote( *it ).local8Bit();
}
status = 0;
- exitqStatus = runGpg( cmd, 0, true );
+ exiStatus = runGpg( cmd, 0, true );
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return KeyList();
}
@@ -470,7 +470,7 @@ int
BaseG::signKey(const KeyID& keyID, const char *passphrase)
{
TQCString cmd;
- int exitqStatus = 0;
+ int exiStatus = 0;
cmd = "--batch";
cmd += addUserId();
@@ -478,9 +478,9 @@ BaseG::signKey(const KeyID& keyID, const char *passphrase)
cmd += keyID;
status = 0;
- exitqStatus = runGpg(cmd.data(), passphrase);
+ exiStatus = runGpg(cmd.data(), passphrase);
- if (exitqStatus != 0)
+ if (exiStatus != 0)
status = ERROR;
return status;
@@ -490,15 +490,15 @@ BaseG::signKey(const KeyID& keyID, const char *passphrase)
TQCString
BaseG::getAsciiPublicKey(const KeyID& keyID)
{
- int exitqStatus = 0;
+ int exiStatus = 0;
if (keyID.isEmpty())
return TQCString();
status = 0;
- exitqStatus = runGpg("--batch --armor --export 0x" + keyID, 0, true);
+ exiStatus = runGpg("--batch --armor --export 0x" + keyID, 0, true);
- if(exitqStatus != 0) {
+ if(exiStatus != 0) {
status = ERROR;
return TQCString();
}
@@ -778,7 +778,7 @@ BaseG::parseKeyData( const TQCString& output, int& offset, Key* key /* = 0 */ )
else {
// assume latin1 encoding
kdDebug(5100) << "Assume latin1 encoding." << endl;
- uidString = TQString::tqfromLatin1( uid.data() );
+ uidString = TQString::fromLatin1( uid.data() );
}
}
userID->setText( uidString );
diff --git a/libkpgp/kpgpblock.cpp b/libkpgp/kpgpblock.cpp
index 4e5f9239..ba1d8fec 100644
--- a/libkpgp/kpgpblock.cpp
+++ b/libkpgp/kpgpblock.cpp
@@ -27,7 +27,7 @@ Block::Block( const TQCString& str )
: mText(str), mProcessedText(), mError(),
mSignatureUserId(), mSignatureKeyId(), mSignatureDate(),
mRequiredKey(), mEncryptedFor(),
- mtqStatus(0), mHasBeenProcessed(false), mType(NoPgpBlock)
+ mStatus(0), mHasBeenProcessed(false), mType(NoPgpBlock)
{
mEncryptedFor.setAutoDelete( true );
}
@@ -46,7 +46,7 @@ Block::reset()
mSignatureDate = TQCString();
mRequiredKey = TQCString();
mEncryptedFor.clear();
- mtqStatus = 0;
+ mStatus = 0;
mHasBeenProcessed = false;
}
diff --git a/libkpgp/kpgpblock.h b/libkpgp/kpgpblock.h
index e3308eab..c5af0241 100644
--- a/libkpgp/kpgpblock.h
+++ b/libkpgp/kpgpblock.h
@@ -58,7 +58,7 @@ typedef enum {
NO_SEC_KEY = 0x0100,
MISSINGKEY = 0x0200,
CANCEL = 0x8000
-} MessagetqStatus;
+} MessageStatus;
class Base;
class Module;
@@ -103,7 +103,7 @@ class KDE_EXPORT Block
void setProcessedText( const TQCString& str );
int status() const;
- void setqStatus( const int status );
+ void seStatus( const int status );
BlockType type();
@@ -186,7 +186,7 @@ class KDE_EXPORT Block
TQCString mRequiredKey;
TQString mRequiredUserId;
TQStrList mEncryptedFor;
- int mtqStatus;
+ int mStatus;
bool mHasBeenProcessed;
BlockType mType;
};
@@ -231,13 +231,13 @@ Block::setError( const TQCString& str )
inline int
Block::status() const
{
- return mtqStatus;
+ return mStatus;
}
inline void
-Block::setqStatus( const int status )
+Block::seStatus( const int status )
{
- mtqStatus = status;
+ mStatus = status;
}
inline BlockType
@@ -317,7 +317,7 @@ Block::encryptedFor() const
inline bool
Block::isEncrypted() const
{
- if( mtqStatus & ENCRYPTED )
+ if( mStatus & ENCRYPTED )
return true;
return false;
}
@@ -325,7 +325,7 @@ Block::isEncrypted() const
inline bool
Block::isSigned() const
{
- if( mtqStatus & SIGNED )
+ if( mStatus & SIGNED )
return true;
return false;
}
@@ -333,7 +333,7 @@ Block::isSigned() const
inline bool
Block::goodSignature() const
{
- if( mtqStatus & GOODSIG )
+ if( mStatus & GOODSIG )
return true;
return false;
}
@@ -342,7 +342,7 @@ Block::goodSignature() const
inline bool
Block::unknownSigner() const
{
- if( mtqStatus & UNKNOWN_SIG )
+ if( mStatus & UNKNOWN_SIG )
return true;
return false;
}
diff --git a/libkpgp/kpgpui.cpp b/libkpgp/kpgpui.cpp
index c9288b01..a9c62d83 100644
--- a/libkpgp/kpgpui.cpp
+++ b/libkpgp/kpgpui.cpp
@@ -126,9 +126,9 @@ Config::Config( TQWidget *parent, const char *name, bool encrypt )
labelFont.setBold( true );
label->setFont( labelFont );
// 3. and activate wordwarp:
- label->tqsetAlignment( AlignLeft|WordBreak );
+ label->setAlignment( AlignLeft|WordBreak );
// end; to remove the workaround, add <qt><b>..</b></qt> around the
// text and remove lines TQFont... -> label->tqsetAlignment(...).
topLayout->addWidget( group );
group = new TQVGroupBox( i18n("Encryption Tool"), this );
@@ -1176,7 +1176,7 @@ KeyRequester::KeyRequester( TQWidget * parent, bool multipleKeys,
// the button to unset any key:
mEraseButton = new TQPushButton( this );
mEraseButton->setAutoDefault( false );
- mEraseButton->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum,
+ mEraseButton->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum,
TQSizePolicy::Minimum ) );
mEraseButton->setPixmap( SmallIcon( "clear_left" ) );
TQToolTip::add( mEraseButton, i18n("Clear") );
@@ -1192,7 +1192,7 @@ KeyRequester::KeyRequester( TQWidget * parent, bool multipleKeys,
connect( mEraseButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotEraseButtonClicked()) );
connect( mDialogButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotDialogButtonClicked()) );
- tqsetSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding,
+ setSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding,
TQSizePolicy::Fixed ) );
}
@@ -1480,21 +1480,21 @@ KeyApprovalDialog::KeyApprovalDialog( const TQStringList& addresses,
// calculate the optimal width for the dialog
int dialogWidth = marginHint()
+ sv->frameWidth()
- + bigvbox->tqsizeHint().width()
- + sv->verticalScrollBar()->tqsizeHint().width()
+ + bigvbox->sizeHint().width()
+ + sv->verticalScrollBar()->sizeHint().width()
+ sv->frameWidth()
+ marginHint()
+ 2;
// calculate the optimal height for the dialog
int dialogHeight = marginHint()
- + label->tqsizeHint().height()
+ + label->sizeHint().height()
+ topLayout->spacing()
+ sv->frameWidth()
- + bigvbox->tqsizeHint().height()
- + sv->horizontalScrollBar()->tqsizeHint().height()
+ + bigvbox->sizeHint().height()
+ + sv->horizontalScrollBar()->sizeHint().height()
+ sv->frameWidth()
+ topLayout->spacing()
- + actionButton( KDialogBase::Cancel )->tqsizeHint().height()
+ + actionButton( KDialogBase::Cancel )->sizeHint().height()
+ marginHint()
+ 2;
// don't make the dialog too large
@@ -126,9 +126,9 @@ Config::Config( TQWidget *parent, const char *name, bool encrypt )
// end; to remove the workaround, add <qt><b>..</b></qt> around the
- // text and remove lines TQFont... -> label->tqsetAlignment(...).
+ // text and remove lines TQFont... -> label->setAlignment(...).
topLayout->addWidget( group );
group = new TQVGroupBox( i18n("Encryption Tool"), this );